birdears package
================

.. automodule:: birdears
   :members:
   :undoc-members:
   :show-inheritance:

Subpackages
-----------

.. toctree::
   :maxdepth: 4

   birdears.interfaces
   birdears.questions

Submodules
----------

birdears.exception module
-------------------------

.. automodule:: birdears.exception
   :members:
   :undoc-members:
   :show-inheritance:

birdears.interval module
------------------------

.. automodule:: birdears.interval
   :members:
   :undoc-members:
   :show-inheritance:

birdears.logger module
----------------------

.. automodule:: birdears.logger
   :members:
   :undoc-members:
   :show-inheritance:

birdears.note\_and\_pitch module
--------------------------------

.. automodule:: birdears.note_and_pitch
   :members:
   :undoc-members:
   :show-inheritance:

birdears.prequestion module
---------------------------

.. automodule:: birdears.prequestion
   :members:
   :undoc-members:
   :show-inheritance:

birdears.questionbase module
----------------------------

.. automodule:: birdears.questionbase
   :members:
   :undoc-members:
   :show-inheritance:

birdears.resolution module
--------------------------

.. automodule:: birdears.resolution
   :members:
   :undoc-members:
   :show-inheritance:

birdears.scale module
---------------------

.. automodule:: birdears.scale
   :members:
   :undoc-members:
   :show-inheritance:

birdears.sequence module
------------------------

.. automodule:: birdears.sequence
   :members:
   :undoc-members:
   :show-inheritance:

birdears.utils module
---------------------

.. automodule:: birdears.utils
   :members:
   :undoc-members:
   :show-inheritance:
